parse_with_children

Function parse_with_children 

pub fn parse_with_children(input: &[u8]) -> Result<ParsedHdf<'_>, ContextError>
Parses an HDF5/SOFA file and returns a navigable structure that allows parsing child objects.

Errors

Returns an error if the input is not a valid HDF5 file or if parsing fails.