Module render

Module render 

This module implements uniformly partitioned convolution algorithm for rendering HRTF filters.

For more details about the alogorithm used check Chapter 5 of Partitioned convolution algorithms for real-time auralization: Book

Structs

Renderer
RendererBuilder

Enums

Error